"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createCompilerOptions = exports.defaultCompilerOptions = void 0;
var tslib_1 = require("tslib");
var typescript_1 = require("typescript");
var logger_1 = require("./logger");
/**
 * Default compiler options.
 * @internal
 */
exports.defaultCompilerOptions = {
    module: typescript_1.ModuleKind.ESNext,
    target: typescript_1.ScriptTarget.ES2016,
    sourceMap: false
};
/**
 * Prepare typescript compiler options.
 * @internal
 * @param cwd - running dir
 * @param options - custom compiler options
 * @param logger - logger
 */
var createCompilerOptions = function (cwd, options, logger) {
    if (options === void 0) { options = {}; }
    if (logger === void 0) { logger = console; }
    var tsConfigFile = options.tsConfigFile;
    var configJson = {
        compilerOptions: options.compilerOptions
    };
    // if not provided we will lookup for existing default
    if (!tsConfigFile) {
        tsConfigFile = (0, typescript_1.findConfigFile)(cwd, typescript_1.sys.fileExists);
    }
    // if no config throe message
    if (!tsConfigFile) {
        logger.warn('tsconfig.json not found ! ' +
            'The default minimal config will be used. ' +
            'You can provide tsconfig.json in working dir, ' +
            'or set custom path in options, like: typescriptCompileMiddleware({ compile: { tsConfigFile: \'./path/to/custom-tsconfig.json\'} })');
    }
    else {
        logger.debug("tsconfig.json found: " + tsConfigFile);
        // reading config file
        var configFile = (0, typescript_1.readConfigFile)(tsConfigFile, typescript_1.sys.readFile);
        if (!configFile.error) {
            configJson = (0, tslib_1.__assign)((0, tslib_1.__assign)({}, configFile.config), { compilerOptions: (0, tslib_1.__assign)((0, tslib_1.__assign)({}, configFile.config.compilerOptions), options.compilerOptions) });
        }
        else {
            throw new Error("tsconfig.json parse error !\n" + (0, logger_1.diagnosticToString)([configFile.error], cwd));
        }
    }
    // parse config file
    var parsedConfig = (0, typescript_1.parseJsonConfigFileContent)(configJson, {
        fileExists: typescript_1.sys.fileExists,
        readDirectory: typescript_1.sys.readDirectory,
        readFile: typescript_1.sys.readFile,
        useCaseSensitiveFileNames: false,
    }, cwd, undefined, tsConfigFile);
    var module = parsedConfig.options.module;
    // warn about improper module
    if (module === typescript_1.ModuleKind.CommonJS
        || module === typescript_1.ModuleKind.AMD
        || module === typescript_1.ModuleKind.System
        || module === typescript_1.ModuleKind.None
        || module === typescript_1.ModuleKind.UMD) {
        logger.warn('typescript compilerOptions \'module\' option is not ' +
            ' ES module, this will probably cause the problem with the script loading to the browser,' +
            ' please use ES2015, ES2020, or ESNext');
    }
    return (0, tslib_1.__assign)((0, tslib_1.__assign)({}, exports.defaultCompilerOptions), parsedConfig.options);
};
exports.createCompilerOptions = createCompilerOptions;
//# sourceMappingURL=create-compiler-options.js.map